



--==========================================================================================================================================

local iOriginalUnit = GameInfo.Units["UNIT_WARRIOR"].Index
local iNewUnit = GameInfo.Units["UNIT_SCOUT"].Index
local iTurnIncrement = 1

--==========================================================================================================================================


function GetEmptyPlotAndMakeUnit(iPlayer, pPlayerUnits, iUnitType, iPlotX, iPlotY)
	local pOriginPlot = Map.GetPlot(iPlotX, iPlotY)
	local tTableOfPlots, iTableLength = {}, 0
	local tUnitDetails = GameInfo.Units[iUnitType]
	if (pOriginPlot ~= nil) then
		for direction = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
			local adjacentPlot = Map.GetAdjacentPlot(iPlotX, iPlotY, direction);
			if (adjacentPlot) then
				--print("GetEmptyPlotAndMakeUnit: plot is valid")
				local bAddPlot = true
				if (adjacentPlot:GetOwner() > -1) and (adjacentPlot:GetOwner() ~= iPlayer) then
					--print("GetEmptyPlotAndMakeUnit: plot is owned by a different player")
					bAddPlot = false
				end
				if bAddPlot then
					if not adjacentPlot:IsMountain() then
						--print("GetEmptyPlotAndMakeUnit: plot is not a mountain")
						if (tUnitDetails.Domain == "DOMAIN_LAND") then
							--print("GetEmptyPlotAndMakeUnit: The desired unit is of DOMAIN_LAND")
							if adjacentPlot:IsWater() then
								--print("GetEmptyPlotAndMakeUnit: The plot is of Water so is invalid")
								bAddPlot = false
							end
							if adjacentPlot:IsCity() then
								--print("GetEmptyPlotAndMakeUnit: The plot is a city so is invalid")
								bAddPlot = false
							end
						elseif (tUnitDetails.Domain == "DOMAIN_SEA") then
							--print("GetEmptyPlotAndMakeUnit: The desired unit is of DOMAIN_SEA")
							if not adjacentPlot:IsWater() then
								--print("GetEmptyPlotAndMakeUnit: The plot is NOT Water so is invalid")
								bAddPlot = false
							end
							if adjacentPlot:IsLake() then
								--print("GetEmptyPlotAndMakeUnit: The plot is a Lake so is invalid")
								bAddPlot = false
							end
							if adjacentPlot:IsCity() then
								--print("GetEmptyPlotAndMakeUnit: The plot is a City so is invalid")
								bAddPlot = false
							end
						else
							--print("GetEmptyPlotAndMakeUnit: The desired unit NOT of DOMAIN_LAND or DOMAIN_SEA")
							if not adjacentPlot:IsCity() then
								--print("GetEmptyPlotAndMakeUnit: The plot is NOT a City so is invalid")
								bAddPlot = false
							end
						end
						if bAddPlot then
							local unitList:table = Units.GetUnitsInPlotLayerID( adjacentPlot:GetX(), adjacentPlot:GetY(), MapLayers.ANY );
							if unitList ~= nil and (table.count(unitList) > 0) then
								--print("GetEmptyPlotAndMakeUnit: The plot has other units so is invalid")
								bAddPlot = false
							end
						end
						if bAddPlot then
							--print("GetEmptyPlotAndMakeUnit: The plot was added to table tTableOfPlots")
							table.insert(tTableOfPlots, adjacentPlot)
							iTableLength = iTableLength + 1
						end
					end
				end
			end
		end
	end
	if (tTableOfPlots ~= nil) and (iTableLength > 0) then
		--print("GetEmptyPlotAndMakeUnit: Table tTableOfPlots was not nil and iTableLength > 0")
		local iSelection = math.random(iTableLength)
		local pPlot = tTableOfPlots[iSelection]
		local pNewUnit = pPlayerUnits:Create(iUnitType, pPlot:GetX(), pPlot:GetY())
		return pNewUnit
	else
		--print("GetEmptyPlotAndMakeUnit: Either Table tTableOfPlots was nil and iTableLength = 0")
	end
	return
end
-- ===========================================================================
--	Game Engine Event
-- ===========================================================================
function OnPlayerTurnActivated(iPlayer, bIsFirstTime)
	--print("Game.GetCurrentGameTurn() = " .. Game.GetCurrentGameTurn())
	--print("(Game.GetCurrentGameTurn() % iTurnIncrement = " .. (Game.GetCurrentGameTurn() % iTurnIncrement))
	if ((Game.GetCurrentGameTurn() % iTurnIncrement) == 0) and (Game.GetCurrentGameTurn() > GameConfiguration.GetStartTurn()) then
		--print("Running Code for Player # " .. iPlayer)
		local pPlayer = Players[iPlayer]
		local pPlayerUnits = pPlayer:GetUnits()
		for i, pUnit in pPlayerUnits:Members() do
			--print("Player # " .. iPlayer .. " has a unit")
			if (pUnit:GetType() == iOriginalUnit) then
				--print("The Unit Type value is the same as iOriginalUnit: " .. iOriginalUnit .. " which evaluates to " .. GameInfo.Units[pUnit:GetType()].UnitType)
				GetEmptyPlotAndMakeUnit(iPlayer, pPlayerUnits, iNewUnit, pUnit:GetX(), pUnit:GetY())
			else
				--print("The Unit Type value is " .. pUnit:GetType() .. " which evaluates to " .. GameInfo.Units[pUnit:GetType()].UnitType)
			end
		end
	end
end


--==================================================================================================================================================
--	Game Loading Actions
--==================================================================================================================================================

function OnLoadScreenClose()
	print("Activating Game Events")
	Events.PlayerTurnActivated.Add(OnPlayerTurnActivated)
end
Events.LoadScreenClose.Add(OnLoadScreenClose)






